@@ -25,6 +25,14 @@ USE_LOGLEVELMAX = '@use_loglevelmax@'
 
 SELF = os.path.basename(sys.argv[0])
 
+# this is dumb, but gets the job done
+PART2TIMER = {
+    'apt-compat': 'apt-daily',
+    'dpkg': 'dpkg-db-backup',
+    'plocate': 'plocate-updatedb',
+}
+
+
 for pgm in ('/usr/sbin/sendmail', '/usr/lib/sendmail'):
     if os.path.exists(pgm):
         HAS_SENDMAIL = True
@@ -574,7 +582,9 @@ def main():
             for filename in CRONTAB_FILES:
                 job_template['p'] = period
                 basename = os.path.basename(filename)
+                basename_distro = PART2TIMER.get(basename, basename)
                 if (os.path.exists('/lib/systemd/system/%s.timer' % basename)
+                 or os.path.exists('/lib/systemd/system/%s.timer' % basename_distro)
                  or os.path.exists('/etc/systemd/system/%s.timer' % basename)):
                     log(5, 'ignoring %s because native timer is present' % filename)
                     continue
